"use strict";

const BbPromise = require('bluebird'),
	rimraf = require('bluebird-rimraf'),
	mkdirp = BbPromise.promisify(require('mkdirp')),
	ncp = BbPromise.promisify(require('ncp').ncp),
	less = require('less'),
	glob = BbPromise.promisify(require('glob')),
	fs = BbPromise.promisifyAll(require('fs')),
	path = require('path')

function exitWithError(e) {
	if (e) {
		console.error(e)
		process.exit(1)
	}
}

function excludeThemeJsonFilter(f) {
	return !/theme.json$/.test(f)
}

console.log('Copying files to client/dist')
rimraf('./client/dist')
	.then(() => mkdirp('./client/dist/jquery'))
	.then(() => mkdirp('./client/dist/bootstrap'))
	.then(() => ncp('./themes/', 'client/dist', { filter: excludeThemeJsonFilter }))
	.then(() => ncp('./node_modules/less/dist', 'client/dist/less'))
	.then(() => ncp('./node_modules/bootstrap/less', 'client/dist/bootstrap/less'))
	.then(() => ncp('./node_modules/bootstrap/dist/js', 'client/dist/bootstrap/js'))
	.then(() => ncp('./node_modules/bootstrap/dist/fonts', 'client/dist/bootstrap/fonts'))
	.then(() => ncp('./node_modules/jquery/dist/', 'client/dist/jquery'))
	.then(() => glob('./themes/*/theme.less')
		.then(files => {
			let promise = BbPromise.resolve()

			files.forEach(f => {
				let theme = path.basename(path.dirname(f))

				promise.then(() => less.render(fs.readFileSync(`./client/dist/${theme}/theme.less`, 'utf8'), { paths: [`./client/dist/${theme}`] })
					.then(output => fs.writeFileAsync(`./client/dist/${theme}/theme.css`, output.css, 'utf8')))

			})

			return promise
		}))
	.catch(exitWithError)
