'use strict'

const fs                      = require('fs'),
	  path                    = require('path'),
	  themeDescriptorFileName = 'theme.json'

function getThemes() {
	let themesDir = `${__dirname}/themes`
	let themes = []
	fs.readdirSync(themesDir).forEach(dir => {
		let themeJsonFileName = path.join(themesDir, dir, themeDescriptorFileName)
		try {
			let themeJson = JSON.parse(fs.readFileSync(themeJsonFileName));
			if (!themeJson.name) {
				throw `Theme should provide a nice display name in ${themeDescriptorFileName} using property name`
			}
			if (!themeJson.description) {
				throw `Theme should provide a nice description in ${themeDescriptorFileName} using property description`
			}
			themes.push(
				{
					id: dir.toLowerCase(),
					name: themeJson.name,
					description: themeJson.description
				}
			)
		} catch (e) {
			throw `Error reading ${themeJsonFileName}: ${e}`
		}
	})
	return themes
}

function listThemes() {
	getThemes().forEach(theme => console.log(theme))
}

/**
 Can use -l or --list to display what was found.
 */
if (process.argv.find(arg => /^(\-l|\-\-list)$/.test(arg))) {
	try {
		listThemes()
	} catch (e) {
		console.error(e)
		process.exit(1)
	}
}

module.exports = {getThemes, listThemes}
